# README

Friday, 21 December 2018, 15:12

This API Proxy shows how you can effectively read the content of a simple XML, within a stylesheet that operates on another XML.

A normal XSL transform accepts an input document and a stylesheet and
emits an output document, typically but not always XML.

    +-----------+
    | XML doc1  | --\
    +-----------+    \                        +-----------+
                      -->  [ transform ] -->  |  XML doc2 |
    +-----------+    /                        +-----------+
    | XSL sheet | --/
    +-----------+


The goal here is to extend that idea a bit, and accept additional metadata
that referenced by the stylesheet to drive the transform.

    +-----------+
    | metadata  | --\
    +-----------+    \
                      \
    +-----------+      \                       +-----------+
    | XML doc1  | ------->  [ transform ] -->  |  XML doc2 |
    +-----------+      /                       +-----------+
                      /
    +-----------+    /
    | XSL sheet | --/
    +-----------+

In XSL, there are supported ways to instantiate a second XML document.
In Apigee Edge you can reference an external URL, with the following:

    <xsl:stylesheet version="1.0"
                    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

      <!-- these are parameters set in the XSL Policy config -->
      <xsl:param name="url1" select="''"/>

      <!-- the following retrieves the remote documents into variables
           available to the stylesheet -->
      <xsl:variable name="xdoc1" select="document($url1)"/>

In the above, the url1 must be passed as a parameter to the sheet, something like this:

    <XSL name='XSL-1'>
      <Source>response</Source>
      <OutputVariable>transformed_content</OutputVariable>
      <ResourceURL>xsl://sheet.xsl</ResourceURL>
      <Parameters ignoreUnresolvedVariables='true'>
        <Parameter name='url1'>https://foo.bar/doc1</Parameter>
      </Parameters>
    </XSL>


There is an alternative: transform the orignal XML into a string, and reference THAT in the XSL.

This proxy shows how that would work.

To invoke it,
deploy it to any environment, then

```
curl -i https://$ORG-$ENV.apigee.net/annapurna-xsl/t1 
```
