<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/"
                exclude-result-prefixes="soap">

  <xsl:output method="xml"
              encoding="utf-8"
              indent="yes"
              xslt:indent-amount="2" xmlns:xslt="http://xml.apache.org/xslt" />
  <xsl:strip-space elements="*"/>

  <!-- these are parameters set in the XSL Policy config -->
  <xsl:param name="metadata" select="''"/>

  <xsl:template match="/soap:Body">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="Update">
    <Update>
      <Account><xsl:value-of select="Account/text()"/></Account>
      <xsl:apply-templates select="*[not(name()='Account')]"/>
    </Update>
  </xsl:template>

  <xsl:template match="Records">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="Record">
    <Record>
      <Id><xsl:value-of select="Id/text()"/></Id>
      <xsl:for-each select="Fields/Pair">
        <xsl:call-template name="xform_pair">
          <xsl:with-param name="inputpair" select="." />
        </xsl:call-template>
      </xsl:for-each>
    </Record>
  </xsl:template>

    <xsl:template name="xform_pair">
      <xsl:param name="inputpair" />
      <xsl:for-each select="tokenize($metadata,'\|')">
        <xsl:call-template name="check_one_pair">
          <xsl:with-param name="mapitem" select="tokenize(.,':')" />
          <xsl:with-param name="inputpair" select="$inputpair" />
        </xsl:call-template>
      </xsl:for-each>
    </xsl:template>

    <xsl:template name="check_one_pair">
      <!-- mapitem is nodeset like: [30030, memo] -->
      <xsl:param name="mapitem" />
      <xsl:param name="inputpair" />

      <xsl:choose>
        <xsl:when test="$inputpair/Name = $mapitem[1]">
          <xsl:element name="{$mapitem[2]}">
            <xsl:if test="$inputpair/StringValue/text()">
              <str><xsl:value-of select="$inputpair/StringValue/text()"/></str>
            </xsl:if>

            <xsl:if test="$inputpair/IntValue/text()">
              <int><xsl:value-of select="$inputpair/IntValue/text()"/></int>
            </xsl:if>
            <xsl:if test="$inputpair/DoubleValue/text()">
              <dbl><xsl:value-of select="$inputpair/DoubleValue/text()"/></dbl>
            </xsl:if>
          </xsl:element>
        </xsl:when>
      </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
